@@ -28,11 +28,9 @@
  */
 
 #define MAKE_NCPLIB
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
-#include "ncplib_i.h"
+#include "../../lib/ncplib_i.h"
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -41,7 +39,7 @@
 #include <errno.h>
 #include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -76,8 +74,8 @@ int main(int argc, char *argv[]) {
 	size_t sslen = 2;
 		
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -124,17 +122,17 @@ int main(int argc, char *argv[]) {
 		fprintf(stderr, "Cannot get entry info: %s\n",
 			strerror(dserr));
 	} else {
-		struct nw_info_struct nw;
+		struct nw_info_struct2 nw;
 
-		dserr = ncp_obtain_file_or_subdir_info(conn, NW_NS_DOS, destns, SA_ALL, RIM_DIRECTORY,
-			nwccre.volume, nwccre.dirEnt, NULL, &nw);
+		dserr = ncp_ns_obtain_entry_info(conn, NW_NS_DOS, SA_ALL, NCP_DIRSTYLE_DIRBASE, 
+				nwccre.volume, nwccre.dirEnt, NULL, 0, destns, RIM_DIRECTORY, &nw, sizeof(nw));
 		if (dserr)
 			fprintf(stderr, "Cannot convert DOS entry to %u-NS entry: %s (%08X)\n", destns, strnwerror(dserr), dserr);
 		else {
 			NWDIRLIST_HANDLE handle;
 			
-			dserr = ncp_ns_search_init(conn, destns, searchattr, 1, nw.volNumber, nw.dirEntNum, NULL, 0,
-					0, sstr, sslen, RIM_ALL, &handle);
+			dserr = ncp_ns_search_init(conn, destns, searchattr, 1, nw.Directory.volNumber, nw.Directory.dirEntNum, NULL, 0,
+					0, sstr, sslen, RIM_NAME, &handle);
 			if (dserr)
 				fprintf(stderr, "Initialize search failed: %s (%08X)\n", strnwerror(dserr), dserr);
 			else {
