@@ -27,8 +27,6 @@
 
  */
 
-#include "config.h"
-
 #include <ncp/nwcalls.h>
 #include <ncp/nwnet.h>
 
@@ -36,8 +34,9 @@
 #include <stdlib.h>
 #include <ctype.h>
 #include <wchar.h>
+#include <string.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
@@ -66,16 +65,16 @@ int main(int argc, char *argv[]) {
 	NWDSCCODE dserr;
 	NWDSContextHandle ctx;
 	NWCONN_HANDLE conn;
-	char* context = "OrgUnit.Org.Country";
+	const char* context = "OrgUnit.Org.Country";
 	unsigned char buff[1000];
-	char* server = "CDROM";
+	const char* server = "CDROM";
 	int opt;
 	u_int32_t ctxflag = 0;
 	u_int32_t nameform = 0;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -173,6 +172,7 @@ int main(int argc, char *argv[]) {
 					size_t len;
 					Net_Address_T* p;
 					u_int8_t* v;
+					int printed = 0;
 									
 					dserr = NWDSComputeAttrValSize(ctx, b, SYN_NET_ADDRESS, &len);
 					if (dserr) {
@@ -193,13 +193,50 @@ int main(int argc, char *argv[]) {
 						free(p);
 						break;
 					}
-					printf("Address: %d, len: %d, content: ", p->addressType, p->addressLength);
-					len = p->addressLength;
 					v = p->address;
-					while (len--) {
-						printf("%02X ", *v++);
+					len = p->addressLength;
+					switch (p->addressType) {
+						case NT_IPX:
+							if (len != 12)
+								break;
+							printf("IPX: %02X%02X%02X%02X:%02X%02X%02X%02X%02X%02X/%02X%02X\n",
+								v[0], v[1], v[2], v[3], 
+								v[4], v[5], v[6], v[7], v[8], v[9],
+								v[10], v[11]);
+							printed = 1;
+							break;
+						case NT_UDP:
+							if (len != 6)
+								break;
+							printf("UDP: %d.%d.%d.%d:%d\n",
+								v[2], v[3], v[4], v[5], v[0] * 256 + v[1]);
+							printed = 1;
+							break;
+						case NT_TCP:
+							if (len != 6)
+								break;
+							printf("TCP: %d.%d.%d.%d:%d\n",
+								v[2], v[3], v[4], v[5], v[0] * 256 + v[1]);
+							printed = 1;
+							break;
+						case 13:
+							printf("URL: ");
+							while (len) {
+								printf("%c", *v);
+								v += 2;
+								len -= 2;
+							}
+							printf("\n");
+							printed = 1;
+							break;
+					}
+					if (!printed) {
+						printf("Address: %d, len: %d, content: ", p->addressType, p->addressLength);
+						while (len--) {
+							printf("%02X ", *v++);
+						}
+						printf("\n");
 					}
-					printf("\n");
 					free(p);
 				}
 			}
