@@ -720,6 +720,7 @@ long
 #define NWE_LOGIN_LOCKOUT		(NWE_SERVER_ERROR | 0xC5)
 #define NWE_Q_NO_RIGHTS			(NWE_SERVER_ERROR | 0xD3)
 #define NWE_Q_NO_JOB			(NWE_SERVER_ERROR | 0xD5)
+#define NWE_Q_NO_JOB_RIGHTS		(NWE_SERVER_ERROR | 0xD6)
 #define NWE_PASSWORD_UNENCRYPTED	(NWE_SERVER_ERROR | 0xD6)
 #define NWE_PASSWORD_NOT_UNIQUE		(NWE_SERVER_ERROR | 0xD7)
 #define NWE_PASSWORD_TOO_SHORT		(NWE_SERVER_ERROR | 0xD8)
@@ -1026,11 +1027,18 @@ long
 long
  ncp_finish_servicing_job(NWCONN_HANDLE conn, NWObjectID queue_id,
 			  u_int32_t job_number, u_int32_t charge_info);
+			  
+long
+ ncp_change_job_position(NWCONN_HANDLE conn, NWObjectID queue_id,
+			  u_int32_t job_number, unsigned int position);
 
 long
  ncp_abort_servicing_job(NWCONN_HANDLE conn, NWObjectID queue_id,
 			 u_int32_t job_number);
 
+NWCCODE NWChangeQueueJobEntry(NWCONN_HANDLE conn, NWObjectID queue_id,
+			      const struct nw_queue_job_entry *jobdata);
+
 long
  ncp_get_broadcast_message(NWCONN_HANDLE conn, char message[256]);
 
