@@ -30,12 +30,15 @@ extern "C" {
 #endif
 
 int strlen_u(const uni_char *s);
+uni_char getchr_u(const uni_char *s);
 void strcpy_uc(char *d, const uni_char *s);
 void strcpy_cu(uni_char *d, const char *s);
-long nds_get_server_name(struct ncp_conn *conn, uni_char **server_name);
-long nds_get_tree_name(struct ncp_conn *conn, char *name, int name_buf_len);
-long nds_login_auth(struct ncp_conn *conn, const char *user, const char *pwd);
-long nds_read(struct ncp_conn *conn, u_int32_t object_id, uni_char *prop_name,
+long nds_get_server_name(NWCONN_HANDLE conn, uni_char **server_name);
+long nds_get_tree_name(NWCONN_HANDLE conn, char *name, int name_buf_len);
+long nds_login_auth(NWCONN_HANDLE conn, const char *user, const char *pwd);
+long nds_resolve_name(struct ncp_conn *conn, int flags, uni_char *entry_name,
+	int *entry_id, int *remote, struct sockaddr *serv_addr, size_t *addr_len);
+long nds_read(NWCONN_HANDLE conn, u_int32_t object_id, uni_char *prop_name,
 	u_int32_t *syntax_id, void **outbuf, size_t *outlen);
 
 #ifdef __cplusplus
