@@ -696,6 +696,63 @@ NWDSCCODE NWDSGetKeys(
 	return 0;
 }
 
+static NWDSCCODE NWDXUpdateKey(
+		NWDS_HANDLE dxh,
+		NWCONN_HANDLE conn
+) {
+	size_t authinfo_len;
+	union __NWDSAuthInfo* ndai;
+	NWDSCCODE err;
+
+	if (conn->nds_conn != dxh) {
+		return NWE_PARAM_INVALID;
+	}
+	if (dxh->authinfo) {
+		return EBUSY;
+	}
+	err = ncp_get_private_key(conn, NULL, &authinfo_len);
+	if (err)
+		return err;	/* kernel without private key support */
+	if (!authinfo_len)
+		return ERR_NOT_LOGGED_IN;	/* no private key on this connection */
+	ndai = (union __NWDSAuthInfo*)malloc(authinfo_len);
+	if (!ndai)
+		return ENOMEM;	/* not enough memory */
+	err = ncp_get_private_key(conn, ndai, &authinfo_len);
+	if (err) {
+		free(ndai);
+		return err;
+	}
+	mlock(ndai, authinfo_len);
+	NWDXSetKeysOnConns(dxh, ndai, authinfo_len);
+	if (dxh->authinfo) {
+		size_t tlen = dxh->authinfo->header.total;
+		memset(dxh->authinfo, 0, tlen);
+		munlock(dxh->authinfo, tlen);
+		free(dxh->authinfo);
+	}
+	dxh->authinfo = ndai;
+	return 0;
+}
+
+/* FIXME: Internal only! */
+static NWDSCCODE NWDXAddConnection(NWDS_HANDLE dsh, NWCONN_HANDLE conn) {
+	ncpt_mutex_lock(&nds_ring_lock);
+	list_del(&conn->nds_ring);
+	conn->state++;
+	list_add(&conn->nds_ring, &dsh->conns);
+	conn->nds_conn = dsh;
+	ncpt_mutex_unlock(&nds_ring_lock);
+	if (!dsh->authinfo) {
+		NWDXUpdateKey(dsh, conn);
+	}
+	return 0;
+}
+
+NWDSCCODE NWDSAddConnection(NWDSContextHandle ctx, NWCONN_HANDLE conn) {
+	return NWDXAddConnection(ctx->ds_connection, conn);
+}
+
 #define xprintf(X...)
 
 NWDSCCODE __NWDSGetPrivateKey(
