@@ -32,6 +32,7 @@
 
 #include "config.h"
 
+#include <string.h>
 #include <ncp/nwnet.h>
 #include "private/list.h"
 #include "private/libncp-lock.h"
@@ -70,7 +71,7 @@ wchar_t* wcsrev(wchar_t*);
 
 size_t unilen(const unicode*);
 
-#ifdef HAVE_ICONV_H
+#ifdef HAVE_ICONV
 #include <iconv.h>
 #endif
 
@@ -79,7 +80,7 @@ typedef struct {
 #define MY_ICONV_LIBC		1
 	int	type;
 	union {
-#ifdef HAVE_ICONV_H
+#ifdef HAVE_ICONV
 		iconv_t h;
 #endif
 		int (*proc)(const char** fa, size_t* fl, char** ta, size_t* tl);
@@ -89,6 +90,8 @@ typedef struct {
 my_iconv_t my_iconv_open(const char* a, const char* b);
 int my_iconv_close(my_iconv_t handle);
 int my_iconv(my_iconv_t, const char** fa, size_t* fl, char** ta, size_t* tl);
+int iconv_external_to_wchar_t(const char* src, wchar_t* dst, size_t maxl);
+int iconv_wchar_t_to_external(const wchar_t* src, char* dst, size_t maxl);
 
 union __NWDSAuthInfo {
 	struct {
@@ -104,7 +107,7 @@ union __NWDSAuthInfo {
 
 typedef struct NWDSConnection {
 	struct {
-		wchar_t	*tree_name;
+		wchar_t*	tree_name;
 			      } dck;
 	struct list_head	conns;
 	struct list_head	contexts;
@@ -116,8 +119,12 @@ struct RDNInfo {
 	size_t			depth;
 };
 
+struct TreeList;
+
 #define DCK_RDN		6	/* internal flag for NWDSGetContext */
 
+#define DCK_TREELIST	17	/* internal... */
+
 struct __NWDSContextHandle {
 	struct {
 		nuint32		flags;
@@ -133,6 +140,7 @@ struct __NWDSContextHandle {
 		struct RDNInfo	rdn;
 		wchar_t*	namectx;
 		nuint32		dsi_flags;
+		struct TreeList* tree_list;
 		      } dck;
 	struct {
 		my_iconv_t	to;
@@ -168,7 +176,6 @@ static inline NWDSCCODE NWDSIsContextValid(NWDSContextHandle ctx) {
 	return ctx ? 0 : ERR_BAD_CONTEXT;
 }
 
-NWDSCCODE NWDSAddConnection(NWDSContextHandle ctx, NWCONN_HANDLE conn);
 NWDSCCODE __NWDSGetConnection(NWDSContextHandle ctx, NWCONN_HANDLE *conn);
 
 /************************************************************************
@@ -403,6 +410,12 @@ NWDSCCODE NWDSPutAttrVal_TIMESTAMP(
 		Buf_T* buffer,
 		const TimeStamp_T* stamp);
 						
+NWDSCCODE NWDSXlateFromCtx(NWDSContextHandle ctx, wchar_t* dst,
+		size_t maxlen, const void* src);
+		
+NWDSCCODE NWDSXlateToCtx(NWDSContextHandle ctx, void* data, 
+		size_t maxlen, const wchar_t* src, size_t* ln);
+
 /************************************************************************
  *									*
  *  NWDS internal server calls						*
@@ -429,6 +442,7 @@ NWDSCCODE NWDSPutAttrVal_TIMESTAMP(
 
 #define DS_RESOLVE_REPLY_LOCAL_ENTRY	0x0001
 #define DS_RESOLVE_REPLY_REMOTE_ENTRY	0x0002
+#define DS_RESOLVE_REPLY_ALIAS		0x0003
 #define DS_RESOLVE_REPLY_REFERRAL	0x0004
 #define DS_RESOLVE_REPLY_REFERRAL_AND_ENTRY 0x0006
 
@@ -559,6 +573,10 @@ NWDSCCODE __NWDSReadObjectDSIInfo(
 		nuint32			dsiFlags,
 		Buf_T*			dsiInfo);
 
+NWDSCCODE NWDSDuplicateContextHandleInt(
+		NWDSContextHandle	srcctx,
+		NWDSContextHandle*	wctx);
+
 #include "iterhandle.h"
 
 #endif	/* __NWNET_I_H__ */
