@@ -548,6 +548,8 @@ void init_mount_info(struct ncp_mount_info *info) {
 
 	memset(info, 0, sizeof(*info));
 
+	myuid = getuid();
+
 	info->version = -1;
 	info->flags = MS_MGC_VAL;
 	info->sig_level = -1;
@@ -557,8 +559,6 @@ void init_mount_info(struct ncp_mount_info *info) {
 	info->pathlen = 1;
 	info->passwd_fd = ~0;
 
-	myuid = getuid();
-
 	info->mdata.mounted_uid = myuid;
 	info->mdata.uid = myuid;
 	info->mdata.gid = getgid();
@@ -578,6 +578,10 @@ void init_mount_info(struct ncp_mount_info *info) {
 	info->mdata.mounted_vol = "";
 	info->upcase_password = 1;
 	info->bcastmode = NWCC_BCAST_PERMIT_ALL; /* all broadcasts by default */
+	
+	if (!suser()) {
+		info->flags |= MS_NODEV | MS_NOEXEC | MS_NOSUID;
+	}
 }
 
 int ncp_mount(const char* mount_name, struct ncp_mount_info* info) {
@@ -1421,6 +1425,26 @@ static void opt_clear_flags(struct ncp_mount_info* info, unsigned int param) {
 	info->flags &= ~param;
 }
 
+static void opt_clear_flags_su(struct ncp_mount_info* info, unsigned int param) {
+	if (info->flags & param) {
+	        if (suser()) {
+			info->flags &= ~param;
+                	return;
+	        }
+        	errexit(82, _("You are not allowed to clear nosuid and nodev flags\n"));
+	}
+}
+
+static void opt_clear_noexec(struct ncp_mount_info* info, unsigned int param) {
+	if (info->flags & param) {
+	        if (suser() || myuid == info->mdata.uid) {
+			info->flags &= ~param;
+                	return;
+	        }
+        	errexit(83, _("You are not allowed to clear noexec flag\n"));
+	}
+}
+
 static void opt_remount(struct ncp_mount_info* info, unsigned int param) __attribute__((noreturn));
 static void opt_remount(struct ncp_mount_info* info, unsigned int param) {
 	errexit(7, _("Remounting not supported, sorry\n"));
@@ -1542,11 +1566,11 @@ static struct optinfo globopts[] = {
 	{0,   "ro",		FN_NOPARAM,	opt_set_flags,		MS_RDONLY},
 	{0,   "rw",		FN_NOPARAM,	opt_clear_flags,	MS_RDONLY},
 	{0,   "nosuid",		FN_NOPARAM,	opt_set_flags,		MS_NOSUID},
-	{0,   "suid",		FN_NOPARAM,	opt_clear_flags,	MS_NOSUID},
+	{0,   "suid",		FN_NOPARAM,	opt_clear_flags_su,	MS_NOSUID},
 	{0,   "nodev",		FN_NOPARAM,	opt_set_flags,		MS_NODEV},
-	{0,   "dev",		FN_NOPARAM,	opt_clear_flags,	MS_NODEV},
+	{0,   "dev",		FN_NOPARAM,	opt_clear_flags_su,	MS_NODEV},
 	{0,   "noexec",		FN_NOPARAM,	opt_set_flags,		MS_NOEXEC},
-	{0,   "exec",		FN_NOPARAM,	opt_clear_flags,	MS_NOEXEC},
+	{0,   "exec",		FN_NOPARAM,	opt_clear_noexec,	MS_NOEXEC},
 	{0,   "sync",		FN_NOPARAM,	opt_set_flags,		MS_SYNCHRONOUS},
 	{0,   "async",		FN_NOPARAM,	opt_clear_flags,	MS_SYNCHRONOUS},
 	{0,   "mand",		FN_NOPARAM,	opt_set_flags,		MS_MANDLOCK},
