@@ -22,12 +22,17 @@
 	0.00  1995			Volker Lendecke
 		Initial revision.
 
- */
+	1.00  2000, October 28		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Changed some constants to symbolic names (SA_*).
 
-#include "config.h"
+	1.01  2001, May 31		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Add include strings.h.
+
+ */
 
 #include <stdio.h>
 #include <string.h>
+#include <strings.h>
 #include <signal.h>
 #include <pwd.h>
 #include <grp.h>
@@ -51,17 +56,17 @@
 #include <ncp/kernel/fs.h>
 #include <ncp/kernel/ncp.h>
 #include <ncp/kernel/ncp_fs.h>
-#include <ncp/ncplib.h>
+#include <ncp/nwcalls.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 static char *progname;
-static char *volname = "SYS";
+static const char *volname = "SYS";
 /*RYP: only on volume "SYS" has "PUBLIC/NLS"*/
 #define TEST_DIRNAME "PUBLIC/NLS" 
 
-void
+static void
 test_connlist(struct ncp_conn *conn)
 {
 	u_int8_t conn_list[256] =
@@ -73,7 +78,7 @@ test_connlist(struct ncp_conn *conn)
 	return;
 }
 
-void
+static void
 test_send(struct ncp_conn *conn)
 {
 	u_int8_t conn_list[256] =
@@ -91,7 +96,8 @@ test_send(struct ncp_conn *conn)
 	}
 	return;
 }
-void
+
+static void
 test_create(struct ncp_conn *conn)
 {
 	long result;
@@ -131,7 +137,7 @@ test_create(struct ncp_conn *conn)
 	printf(_("test_create: Passed.\n"));
 }
 
-int
+static int
 test_change(struct ncp_conn *conn)
 {
 	long result;
@@ -155,7 +161,7 @@ test_change(struct ncp_conn *conn)
 	return 0;
 }
 
-void
+static void
 test_readdir(struct ncp_conn *conn)
 {
 	long	result;
@@ -185,7 +191,7 @@ test_readdir(struct ncp_conn *conn)
 		struct nw_info_struct nfs;
 		printf(_("\tfound\t\t: %s\n"), entry.entryName);
 		if (ncp_obtain_file_or_subdir_info(conn, NW_NS_DOS, NW_NS_NFS,
-						   0x8006, RIM_ALL,
+						   SA_ALL, RIM_ALL,
 						   entry.volNumber,
 						   entry.DosDirNum,
 						   NULL,
@@ -194,7 +200,7 @@ test_readdir(struct ncp_conn *conn)
 			printf(_("\tnfs name\t: %s\n"), nfs.entryName);
 		}
 		if (ncp_obtain_file_or_subdir_info(conn, NW_NS_DOS, NW_NS_OS2,
-						   0x8006, RIM_ALL,
+						   SA_ALL, RIM_ALL,
 						   entry.volNumber,
 						   entry.DosDirNum,
 						   NULL,
@@ -229,7 +235,7 @@ test_readdir(struct ncp_conn *conn)
 		{
 			struct nw_info_struct xxx;
 			printf(_("\tfound %s\t: %s\n"),
-				(entry.attributes & aDIR ? "DIR " : "FILE"),
+				(DVAL_LH(&entry.attributes, 0) & A_DIRECTORY ? "DIR " : "FILE"),
 				entry.entryName);
 			if (ncp_obtain_file_or_subdir_info (
 				conn, NW_NS_DOS, NW_NS_NFS,
@@ -258,7 +264,7 @@ test_readdir(struct ncp_conn *conn)
 	printf(_("test_readdir: Passed.\n"));
 }
 
-void
+static void
 test_rights(struct ncp_conn *conn)
 {
 	long	result;
@@ -277,7 +283,7 @@ test_rights(struct ncp_conn *conn)
 		printf(_("lookup me error\n"));
 		return;
 	}
-	if (ncp_get_eff_directory_rights(conn, 0, 0, 0x8006,
+	if (ncp_get_eff_directory_rights(conn, 0, 0, SA_ALL,
 					 sys.volNumber, sys.DosDirNum, NULL,
 					 &rights) != 0)
 	{
@@ -286,7 +292,7 @@ test_rights(struct ncp_conn *conn)
 	}
 	printf(_("%s right: %4.4x\n"), volname, rights);
 
-	if (ncp_get_eff_directory_rights(conn, 0, 0, 0x8006,
+	if (ncp_get_eff_directory_rights(conn, 0, 0, SA_ALL,
 					 me.volNumber, me.DosDirNum, NULL,
 					 &rights) != 0)
 	{
@@ -331,8 +337,8 @@ main(int argc, char *argv[])
 	int exit_code = 0;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 	if ((conn = ncp_initialize(&argc, argv, 1, &err)) == NULL)
