@@ -21,17 +21,23 @@
 
 	0.00  1996			Volker Lendecke
 		Initial revision.
- */
+		
+	1.01  2001, May 31		Petr Vandrovec <vandrove@vc.cvut.cz>
+		Add include strings.h.
 
-#include "config.h"
+	1.02  2001, September 23	Petr Vandrovec <vandrove@vc.cvut.cz>
+		Return proper error message on error.
+
+ */
 
 #include <ncp/nwcalls.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <string.h>
+#include <strings.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 #define N_(X) (X)
 
@@ -88,8 +94,8 @@ main(int argc, char *argv[])
 	int opt;
 
 	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
 	
 	progname = argv[0];
 
@@ -135,7 +141,7 @@ main(int argc, char *argv[])
 	}
 
 	if (useConn) {
-		char* path;
+		const char* path;
 
 		if (optind < argc)
 			path = argv[optind];
@@ -164,24 +170,19 @@ main(int argc, char *argv[])
 			progname);
 		goto finished;
 	}
-	if (ncp_scan_property(conn, object_type, object_name,
-			      0xffffffff, property_name, &info) != 0)
+	if ((err = ncp_scan_property(conn, object_type, object_name,
+			      0xffffffff, property_name, &info)) != 0)
 	{
-		fprintf(stderr, _("%s: Could not find property\n"), progname);
+		const char* errmsg;
+		
+		if (err == NWE_NCP_NOT_SUPPORTED) {
+			errmsg = _("No such property");
+		} else {
+			errmsg = strnwerror(err);
+		}
+		fprintf(stderr, _("%s: Could not find property: %s\n"), progname, errmsg);
 		goto finished;
 	}
-	segno = 1;
-	while (ncp_read_property_value(conn, object_type, object_name,
-				       segno, property_name, &segment) == 0)
-	{
-		memcpy(&(property_value[(segno - 1) * 128]), segment.value, 128);
-		if ((segment.more_flag == 0) || (segno == 255))
-		{
-			break;
-		}
-		segno += 1;
-	}
-
 	if (canonical != 0)
 	{
 		printf("%-4.4x\n%s\n", object_type, object_name);
@@ -189,6 +190,21 @@ main(int argc, char *argv[])
 		       info.property_name, info.property_flags, info.property_security);
 
 	}
+	segno = 0;
+	while ((err = ncp_read_property_value(conn, object_type, object_name,
+				       segno + 1, property_name, &segment)) == 0)
+	{
+		memcpy(&(property_value[segno * 128]), segment.value, 128);
+		segno++;
+		if (segno == 255) {
+			break;
+		}
+	}
+
+	if (!segno) {
+		fprintf(stderr, _("%s: Could not read property value: %s\n"), progname, strnwerror(err));
+		goto finished;
+	}
 	if ((info.property_flags & 2) == 0)
 	{
 		/* ITEM property */
@@ -276,9 +292,10 @@ print_unknown(u_int8_t * val)
 }
 
 static void
-print_string(u_int8_t * val)
+print_string(u_int8_t * val, int segments)
 {
 	puts(val);
+	(void)segments;
 }
 
 static char *
@@ -328,8 +345,8 @@ print_station_addr(const char *fmt, const struct ncp_station_addr *addr, char *b
 	return ret;
 }
 
-void
-print_login_control(u_int8_t * val)
+static void
+print_login_control(u_int8_t * val, int segments)
 {
 	static const time_t zero_time_t = 0;
 	int i, j, mask;
@@ -469,62 +486,52 @@ print_login_control(u_int8_t * val)
 		}
 		printf("]\n");
 	}
+	(void)segments;
 }
 
 static void
-print_addr(u_int8_t * val)
+print_addr(u_int8_t * val, int segments)
 {
 	char buff[50];
 	print_station_addr("(%L): %N[%S]",
 			   (struct ncp_station_addr *) val, buff);
 	printf("%s\n", buff);
+	(void)segments;
+}
+
+static void
+print_hex(u_int8_t *val, int segments) {
+	int i;
+
+	for (i = 0; i < segments; i++) {
+		printf(_("Segment: %03d\n"), i + 1);
+		print_unknown(val + i * 128);
+		printf("\n");
+	}
 }
 
 static const struct
 {
+	void (*func) (u_int8_t *, int);
 	const char *pname;
-	void (*func) (u_int8_t *);
 }
 formats[] =
 {
-	{
-		"DESCRIPTION", print_string
-	}
-	,
-	{
-		"SURNAME", print_string
-	}
-	,
-	{
-		"OBJECT_CLASS", print_string
-	}
-	,
-	{
-		"IDENTIFICATION", print_string
-	}
-	,
-	{
-		"Q_DIRECTORY", print_string
-	}
-	,
-	{
-		"LOGIN_CONTROL", print_login_control
-	}
-	,
-	{
-		"NET_ADDRESS", print_addr
-	}
-	,
-	{
-		NULL, NULL
-	}
+	{ print_string,		"DESCRIPTION"		},
+	{ print_string,		"SURNAME"		},
+	{ print_string,		"GIVEN_NAME"		},
+	{ print_string,		"OBJECT_CLASS"		},
+	{ print_string,		"IDENTIFICATION"	},
+	{ print_string,		"Q_DIRECTORY"		},
+	{ print_login_control,	"LOGIN_CONTROL"		},
+	{ print_addr,		"NET_ADDRESS"		},
+	{ NULL,			NULL			},
 };
 
 static void
 print_property(char *prop_name, u_int8_t * val, int segments)
 {
 	int i;
-	void (*f) (u_int8_t *);
 
 	for (i = 0; formats[i].pname != NULL; i++)
 	{
@@ -533,17 +540,5 @@ print_property(char *prop_name, u_int8_t * val, int segments)
 			break;
 		}
 	}
-	f = formats[i].func;
-
-	if (f != NULL)
-	{
-		f(val);
-		return;
-	}
-	for (i = 0; i < segments; i++)
-	{
-		printf(_("Segment: %03d\n"), i + 1);
-		print_unknown(&(val[i * 128]));
-		printf("\n");
-	}
+	formats[i].func(val, segments);
 }
