@@ -23,8 +23,6 @@
 		Initial revision.
  */
 
-#include "config.h"
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -38,7 +36,7 @@
 #include <string.h>
 #include <ncp/ncplib.h>
 
-#include <libintl.h>
+#include "private/libintl.h"
 #define _(X) gettext(X)
 
 struct nw_queue
@@ -52,23 +50,13 @@ struct nw_queue
 	char *command;
 };
 
-static struct nw_queue q;
-
-static int term_request;
+static volatile int term_request;
 static char *progname;
 
-static int
- init_queue(struct ncp_conn *conn, char *queue_name,
-	    char *command, struct nw_queue *q);
-
-static int
- poll_queue(struct nw_queue *q);
-
 static void
 usage(void)
 {
 	fprintf(stderr, _("usage: %s [options] file\n"), progname);
-	exit(1);
 }
 
 static void
@@ -96,7 +84,7 @@ help(void)
 #endif
 
 static void
-terminate_handler(int dummy)
+terminate_handler(int dummy __attribute__((unused)))
 {
 	signal(SIGTERM, terminate_handler);
 	signal(SIGINT, terminate_handler);
@@ -126,128 +114,6 @@ daemon_init(void)
 	return 0;
 }
 
-int
-main(int argc, char *argv[])
-{
-	struct ncp_conn *conn;
-	int poll_timeout = 30;
-	int opt;
-	int job_type = 0xffff;
-	int debug = 0;
-	int i;
-	long err;
-
-	char *queue_name = NULL;
-
-	char default_command[] = "lpr";
-	char *command = default_command;
-
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
-	
-	progname = argv[0];
-
-	for (i = 1; i < argc; i += 1)
-	{
-		if ((strcmp(argv[i], "-h") == 0)
-		    || (strcmp(argv[i], "-?") == 0))
-		{
-			help();
-			exit(0);
-		}
-	}
-
-	for (i = 1; i < argc; i += 1)
-	{
-		if (strcmp(argv[i], "-d") == 0)
-		{
-			debug = 1;
-			break;
-		}
-	}
-
-	if (debug == 0)
-	{
-		daemon_init();
-		openlog("pserver", LOG_PID, LOG_LPR);
-	}
-	if ((conn = ncp_initialize_as(&argc, argv, 1,
-				      NCP_BINDERY_PSERVER, &err)) == NULL)
-	{
-		com_err(argv[0], err, _("when initializing"));
-		return 1;
-	}
-	while ((opt = getopt(argc, argv, "q:c:j:t:dh")) != EOF)
-	{
-		switch (opt)
-		{
-		case 'q':
-			queue_name = optarg;
-			break;
-		case 'c':
-			command = optarg;
-			break;
-		case 'j':
-			job_type = atoi(optarg);
-			break;
-		case 't':
-			poll_timeout = atoi(optarg);
-			break;
-		case 'd':
-			debug = 1;
-			break;
-		case 'h':
-			break;
-		default:
-			usage();
-			return -1;
-		}
-	}
-
-	if (argc != optind)
-	{
-		usage();
-		return -1;
-	}
-	memset(&q, 0, sizeof(q));
-
-	if (queue_name == NULL)
-	{
-		fprintf(stderr, _("You must specify a queue\n"));
-		return 1;
-	}
-	if (init_queue(conn, queue_name, command, &q) != 0)
-	{
-		ncp_close(conn);
-		return 1;
-	}
-	q.job_type = job_type;
-
-	term_request = 0;
-	signal(SIGTERM, terminate_handler);
-	signal(SIGINT, terminate_handler);
-
-	while (1)
-	{
-		if ((poll_queue(&q) != 0)
-		    && (term_request == 0))
-		{
-			continue;
-		}
-		if (term_request != 0)
-		{
-			break;
-		}
-		sleep(poll_timeout);
-	}
-
-	ncp_detach_from_queue(conn, q.queue_id);
-
-	ncp_close(conn);
-	return 0;
-}
-
 static int
 init_queue(struct ncp_conn *conn, char *queue_name, char *command,
 	   struct nw_queue *q)
@@ -280,21 +146,21 @@ init_queue(struct ncp_conn *conn, char *queue_name, char *command,
 }
 
 
-void
+static void
 build_command(struct nw_queue *q, struct queue_job *j,
 	      char *target, int target_size, char *user)
 {
 	char *s = q->command;
 	char *target_end = target + target_size;
 
-	void add_string(const char *s)
+	static void add_string(const char *str)
 	{
-		int len = strlen(s);
+		int len = strlen(str);
 		if (target + len + 1 > target_end)
 		{
 			len = target_end - target - 1;
 		}
-		strncpy(target, s, len);
+		strncpy(target, str, len);
 		target += len;
 	}
 
@@ -346,11 +212,14 @@ poll_queue(struct nw_queue *q)
 	struct ncp_bindery_object u;
 	char user[50];
 
-	if (ncp_service_queue_job(q->conn, q->queue_id, q->job_type,
-				  &job) != 0)
-	{
-		/* No job for us */
-		return 0;
+	retcode = ncp_service_queue_job(q->conn, q->queue_id, q->job_type, &job);
+	if (retcode != 0) {
+		if (retcode == NWE_Q_NO_JOB || retcode == NWE_SERVER_FAILURE) {
+			/* No job for us */
+			return 0;
+		}
+		syslog(LOG_ERR, _("Cannot service print job: %s\n"), strnwerror(retcode));
+		return 2;
 	}
 
         if (ncp_get_queue_job_info(q->conn, q->queue_id, job.j.JobNumber, &job.j) != 0)
@@ -441,3 +310,123 @@ poll_queue(struct nw_queue *q)
 	   when something's wrong */
 	return 0;
 }
+
+static struct nw_queue q;
+
+int
+main(int argc, char *argv[])
+{
+	struct ncp_conn *conn;
+	int poll_timeout = 30;
+	int opt;
+	int job_type = 0xffff;
+	int debug = 0;
+	int i;
+	long err;
+
+	char *queue_name = NULL;
+
+	char default_command[] = "lpr";
+	char *command = default_command;
+
+	setlocale(LC_ALL, "");
+	bindtextdomain(NCPFS_PACKAGE, LOCALEDIR);
+	textdomain(NCPFS_PACKAGE);
+	
+	progname = argv[0];
+
+	for (i = 1; i < argc; i += 1)
+	{
+		if ((strcmp(argv[i], "-h") == 0)
+		    || (strcmp(argv[i], "-?") == 0))
+		{
+			help();
+			exit(0);
+		}
+	}
+
+	for (i = 1; i < argc; i += 1)
+	{
+		if (strcmp(argv[i], "-d") == 0)
+		{
+			debug = 1;
+			break;
+		}
+	}
+
+	if (debug == 0)
+	{
+		daemon_init();
+		openlog("pserver", LOG_PID, LOG_LPR);
+	}
+	if ((conn = ncp_initialize_as(&argc, argv, 1,
+				      NCP_BINDERY_PSERVER, &err)) == NULL)
+	{
+		com_err(argv[0], err, _("when initializing"));
+		return 1;
+	}
+	while ((opt = getopt(argc, argv, "q:c:j:t:dh")) != EOF)
+	{
+		switch (opt)
+		{
+		case 'q':
+			queue_name = optarg;
+			break;
+		case 'c':
+			command = optarg;
+			break;
+		case 'j':
+			job_type = atoi(optarg);
+			break;
+		case 't':
+			poll_timeout = atoi(optarg);
+			break;
+		case 'd':
+			debug = 1;
+			break;
+		case 'h':
+			break;
+		default:
+			usage();
+			return -1;
+		}
+	}
+
+	if (argc != optind)
+	{
+		usage();
+		return -1;
+	}
+	memset(&q, 0, sizeof(q));
+
+	if (queue_name == NULL)
+	{
+		fprintf(stderr, _("You must specify a queue\n"));
+		return 1;
+	}
+	if (init_queue(conn, queue_name, command, &q) != 0)
+	{
+		ncp_close(conn);
+		return 1;
+	}
+	q.job_type = job_type;
+
+	term_request = 0;
+	signal(SIGTERM, terminate_handler);
+	signal(SIGINT, terminate_handler);
+
+	while (1)
+	{
+		err = poll_queue(&q);
+		if (term_request || err == 2)
+			break;
+		if (err == 0)
+			sleep(poll_timeout);
+	}
+
+	ncp_detach_from_queue(conn, q.queue_id);
+
+	ncp_close(conn);
+	return 0;
+}
+
